#include "spi.h"
#include "rf69.h"

RF69<SpiDev10> rf;

uint8_t rxBuf[64];
uint8_t txBuf[62];

const int nodeID = 21;
const int tempTag = 0x44;

unsigned long timerStart;
unsigned long timerPeriod = 10000; // ms

void setup () {
  analogReference(INTERNAL);  
  Serial.begin(57600);
  Serial.println("\n[rf69-temp-node]");
  
  rf.init(nodeID, 42, 8686);
  //rf.encrypt("mysecret");
  rf.txPower(31); // 0 = min .. 31 = max
  timerStart = millis();  
}

void loop () {
  if (millis() - timerStart >= timerPeriod) {
    timerStart = timerStart + timerPeriod;
    unsigned int temp = map(analogRead(A0),
        0, 1023, 0, 1100);
    txBuf[0] = tempTag;
    txBuf[1] = temp >> 8;   // hi byte
    txBuf[2] = temp & 0xFF; // lo byte
    rf.send(0, txBuf, 3);
    
    Serial.print("temperature: ");
    Serial.println(temp);
  }
  
  int len = rf.receive(rxBuf, sizeof rxBuf);
  if (len >= 0) {
    Serial.print("OK ");
    for (int i = 0; i < len; ++i) {
      Serial.print(rxBuf[i] >> 4, HEX);
      Serial.print(rxBuf[i] & 0xF, HEX);
    }
    Serial.println();
    
    if (rxBuf[2] == tempTag) {
      Serial.print("Node ");
      Serial.print(rxBuf[1]);
      Serial.print(" temperature: ");
      Serial.println(
        (rxBuf[3] << 8) | rxBuf[4]);
    }
  }
}

